pub struct MultipartReconciliation { /* private fields */ }Expand description
Server-observed state of a live multipart upload.
Implementations
Sourceimpl MultipartReconciliation
impl MultipartReconciliation
Sourcepub fn uploaded_parts(&self) -> impl ExactSizeIterator<Item = &UploadedPart>
pub fn uploaded_parts(&self) -> impl ExactSizeIterator<Item = &UploadedPart>
Returns uploaded parts in ascending part-number order.
Sourcepub fn into_uploaded_parts(self) -> Vec<UploadedPart>
pub fn into_uploaded_parts(self) -> Vec<UploadedPart>
Consumes the reconciliation and returns uploaded parts in ascending part-number order.
Sourcepub fn missing_parts(&self) -> impl ExactSizeIterator<Item = PartNumber> + '_
pub fn missing_parts(&self) -> impl ExactSizeIterator<Item = PartNumber> + '_
Returns planned parts that R2 has not received yet.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Returns whether R2 has every planned part with the expected size.
Sourcepub fn into_completion_manifest(self) -> Result<CompletionManifest, Error>
pub fn into_completion_manifest(self) -> Result<CompletionManifest, Error>
Builds a canonical completion manifest when every part is present.